Error

Enum Error 

pub enum Error<N: Nucleotide>
where <N as FromStr>::Err: Debug + Display,
{ Identical(N), Parse(ParseError<N>), Relation(Error<N>), }
An error related to a Variant.

Variants



Identical(N)

Attempted to create a Variant with identical reference and alternate nucleotides.



Parse(ParseError<N>)

Unsuccessfully attempted to parse a Variant from a string.



Relation(Error<N>)

An error constructing a relation.