pub enum ParseError<N: Nucleotide>{
InvalidFormat(String),
CoordinateError(Error),
ReferenceNucleotide(<N as FromStr>::Err),
AlternateNucleotide(<N as FromStr>::Err),
}Expand description
A parse error related to a Variant.
Variants
InvalidFormat(String)
An invalid format was encountered when parsing a Variant.
CoordinateError(Error)
An issue occurred when parsing the coordinate of the Variant.
ReferenceNucleotide(<N as FromStr>::Err)
An issue occurred when parsing the reference nucleotide of the
Variant.
AlternateNucleotide(<N as FromStr>::Err)
An issue occurred when parsing the alternate nucleotide of the
Variant.