Variant

Struct Variant 

pub struct Variant<N: Nucleotide> { /* private fields */ }
A single nucleotide variant.

Implementations

Source

impl<N: Nucleotide> Variant<N>
where <N as FromStr>::Err: Debug + Display,

pub fn try_new( coordinate: impl Into<Coordinate<Base>>, reference_nucleotide: impl Into<N>, alternate_nucleotide: impl Into<N>, ) -> Result<Self, Error<N>>

Attempts to create a new Variant.

Examples
use omics_coordinate::base::Coordinate;
use omics_coordinate::system::Base;
use omics_molecule::polymer::dna;
use omics_variation::snv::Variant;

let variant = Variant::<dna::Nucleotide>::try_new(
    "seq0:+:1".parse::<Coordinate>()?,
    dna::Nucleotide::A,
    dna::Nucleotide::T,
)?;
pub fn coordinate(&self) -> &Coordinate<Base>

Gets the Coordinate for this Variant.

Examples
use omics_coordinate::Strand;
use omics_coordinate::base::Coordinate;
use omics_coordinate::system::Base;
use omics_molecule::polymer::dna;
use omics_variation::snv::Variant;

let variant = Variant::<dna::Nucleotide>::try_new(
    "seq0:+:1".parse::<Coordinate>()?,
    dna::Nucleotide::A,
    dna::Nucleotide::T,
)?;

assert_eq!(variant.coordinate().contig().as_str(), "seq0");
assert_eq!(variant.coordinate().strand(), Strand::Positive);
assert_eq!(variant.coordinate().position().get(), 1);
pub fn reference(&self) -> &N

Gets the reference nucleotide as a Nucleotide from the Variant.

Examples
use omics_coordinate::base::Coordinate;
use omics_coordinate::system::Base;
use omics_molecule::polymer::dna;
use omics_variation::snv::Variant;

let variant = "seq0:+:1:A:T".parse::<Variant<dna::Nucleotide>>()?;
assert_eq!(variant.reference(), &dna::Nucleotide::A);
pub fn alternate(&self) -> &N

Gets the alternate nucleotide as a Nucleotide from the Variant.

Examples
use omics_coordinate::base::Coordinate;
use omics_coordinate::system::Base;
use omics_molecule::polymer::dna;
use omics_variation::snv::Variant;

let variant = "seq0:+:1:A:T".parse::<Variant<dna::Nucleotide>>()?;
assert_eq!(variant.alternate(), &dna::Nucleotide::T);